Promote a nested field to be represented as a metadata field of the SummarizedExperiment as either the rowData or colData.
Source: R/concatentate_SEs.R
promote_fields.RdPromote a nested field to be represented as a metadata field of the SummarizedExperiment
as either the rowData or colData.
Usage
promote_fields(se, fields, MARGIN = c(1, 2))Examples
mae <- get_synthetic_data("finalMAE_small.qs2")
se <- mae[[1]]
se <- promote_fields(se, "ReadoutValue", 2)
#> Warning: dropping assay 'Controls' from the final SE
#> Warning: dropping assay 'Normalized' from the final SE
#> Warning: dropping assay 'Averaged' from the final SE
#> Warning: dropping assay 'Metrics' from the final SE